@@ -1,6 +1,7 @@
 from pathlib import Path
 from typing import Any, Dict, MutableMapping
 
+from .env_loader import env_loader
 from .json_loader import json_loader
 from .loader import Loader
 from .toml_loader import toml_loader
@@ -8,6 +9,7 @@ from .toml_loader import toml_loader
 __parser_mapping: Dict[str, Loader] = {
     ".json": json_loader,
     ".toml": toml_loader,
+    ".env": env_loader,
 }
 
 
